@@ -8,7 +8,7 @@ Script to convert from one date type to others
 
 import argparse
 
-from pgamit.Utils import process_date
+from pgamit.Utils import process_date, add_version_argument
 
 
 def main():
@@ -19,6 +19,8 @@ def main():
                         help='''Date to convert from. Allowable formats
                         are yyyy/mm/dd yyyy_doy wwww-d format''')
 
+    add_version_argument(parser)
+
     args = parser.parse_args()
 
     dates = process_date(args.date)
