@@ -27,7 +27,7 @@ from tqdm import tqdm
 # app
 from pgamit import dbConnection, pyDate, pyJobServer, pyOptions, pyStationInfo
 from pgamit.pyGamitConfig import GamitConfiguration
-from pgamit.Utils import process_stnlist, stationID, plot_rinex_completion
+from pgamit.Utils import process_stnlist, stationID, plot_rinex_completion, add_version_argument
 
 global kml, folder_project, folder_allstns, stnlist
 
@@ -71,6 +71,8 @@ def main():
     parser.add_argument('-np', '--noparallel', action='store_true',
                         help="Execute command without parallelization.")
 
+    add_version_argument(parser)
+
     args = parser.parse_args()
 
     cnn = dbConnection.Cnn("gnss_data.cfg")
@@ -361,12 +363,14 @@ def generate_kml_stninfo(JobServer, cnn, project, data=False,
 
     # remove the extension if supplied
     ext = os.path.splitext(kmz_filename)
+
+    # DDG Jun 17 2025: the wrong version of simplekml was being used, now using latest
     # to fix the issue from simple kml
     # AttributeError: module 'cgi' has no attribute 'escape'
     # see: https://github.com/tjlang/simplekml/issues/38
-    import cgi
-    import html
-    cgi.escape = html.escape
+    # import cgi
+    # import html
+    # cgi.escape = html.escape
     kml.savekmz(ext[0] + '.kmz')
 
 
@@ -510,12 +514,13 @@ RINEX count: %i PPP soln: %s%%<br><br>
     if not os.path.exists('production'):
         os.makedirs('production')
 
+    # DDG Jun 17 2025: the wrong version of simplekml was being used, now using latest
     # to fix the issue from simple kml
     # AttributeError: module 'cgi' has no attribute 'escape'
     # see: https://github.com/tjlang/simplekml/issues/38
-    import cgi
-    import html
-    cgi.escape = html.escape
+    # import cgi
+    # import html
+    # cgi.escape = html.escape
 
     kml.savekmz('production/' + project + '.kmz')
 
