@@ -20,7 +20,7 @@ from pgamit import pyOptions
 from pgamit import dbConnection
 from pgamit import pyStationInfo
 from pgamit import pyDate
-from pgamit.Utils import process_date
+from pgamit.Utils import process_date, add_version_argument
 
 
 cnn       = dbConnection.Cnn('gnss_data.cfg')
@@ -492,6 +492,8 @@ def main():
 
     parser.add_argument('stn', type=str, nargs=1, help="Station name given in net.stnm format.")
 
+    add_version_argument(parser)
+
     args = parser.parse_args()
 
     stn = args.stn[0]
